<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-dump?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// D
	'dump_description' => 'Copia de seguridad en SQLite y recuperación',
	'dump_slogan' => 'Copia de seguridad y recuperación de la base de datos de SPIP'
);

?>
